@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -28,7 +29,7 @@
 // MARKER(update_precomp.py): autogen include statement, do not remove
 #include "precompiled_sw.hxx"
 
-
+#include <ftnfrm.hxx>
 #include <pagefrm.hxx>
 #include <rootfrm.hxx>
 #include <cntfrm.hxx>
@@ -53,10 +54,9 @@
 #include <fmtclds.hxx>
 #include <viewsh.hxx>
 #include <viewimp.hxx>
-
-// OD 2004-05-24 #i28701#
 #include <sortedobjs.hxx>
 #include <hints.hxx>
+#include <switerator.hxx>
 
     // No inline cause we need the function pointers
 long SwFrm::GetTopMargin() const
@@ -76,55 +76,55 @@ long SwFrm::GetPrtRight() const
 long SwFrm::GetPrtTop() const
     { return Frm().Top() + Prt().Top(); }
 
-BOOL SwFrm::SetMinLeft( long nDeadline )
+sal_Bool SwFrm::SetMinLeft( long nDeadline )
 {
     SwTwips nDiff = nDeadline - Frm().Left();
     if( nDiff > 0 )
     {
         Frm().Left( nDeadline );
         Prt().Width( Prt().Width() - nDiff );
-        return TRUE;
+        return sal_True;
     }
-    return FALSE;
+    return sal_False;
 }
 
-BOOL SwFrm::SetMaxBottom( long nDeadline )
+sal_Bool SwFrm::SetMaxBottom( long nDeadline )
 {
     SwTwips nDiff = Frm().Top() + Frm().Height() - nDeadline;
     if( nDiff > 0 )
     {
         Frm().Height( Frm().Height() - nDiff );
         Prt().Height( Prt().Height() - nDiff );
-        return TRUE;
+        return sal_True;
     }
-    return FALSE;
+    return sal_False;
 }
 
-BOOL SwFrm::SetMinTop( long nDeadline )
+sal_Bool SwFrm::SetMinTop( long nDeadline )
 {
     SwTwips nDiff = nDeadline - Frm().Top();
     if( nDiff > 0 )
     {
         Frm().Top( nDeadline );
         Prt().Height( Prt().Height() - nDiff );
-        return TRUE;
+        return sal_True;
     }
-    return FALSE;
+    return sal_False;
 }
 
-BOOL SwFrm::SetMaxRight( long nDeadline )
+sal_Bool SwFrm::SetMaxRight( long nDeadline )
 {
     SwTwips nDiff = Frm().Left() + Frm().Width() - nDeadline;
     if( nDiff > 0 )
     {
         Frm().Width( Frm().Width() - nDiff );
         Prt().Width( Prt().Width() - nDiff );
-        return TRUE;
+        return sal_True;
     }
-    return FALSE;
+    return sal_False;
 }
 
-void SwFrm::MakeBelowPos( const SwFrm* pUp, const SwFrm* pPrv, BOOL bNotify )
+void SwFrm::MakeBelowPos( const SwFrm* pUp, const SwFrm* pPrv, sal_Bool bNotify )
 {
     if( pPrv )
     {
@@ -140,7 +140,7 @@ void SwFrm::MakeBelowPos( const SwFrm* pUp, const SwFrm* pPrv, BOOL bNotify )
         aFrm.Pos().Y() += 1;
 }
 
-void SwFrm::MakeUpperPos( const SwFrm* pUp, const SwFrm* pPrv, BOOL bNotify )
+void SwFrm::MakeUpperPos( const SwFrm* pUp, const SwFrm* pPrv, sal_Bool bNotify )
 {
     if( pPrv )
     {
@@ -157,7 +157,7 @@ void SwFrm::MakeUpperPos( const SwFrm* pUp, const SwFrm* pPrv, BOOL bNotify )
         aFrm.Pos().Y() -= 1;
 }
 
-void SwFrm::MakeLeftPos( const SwFrm* pUp, const SwFrm* pPrv, BOOL bNotify )
+void SwFrm::MakeLeftPos( const SwFrm* pUp, const SwFrm* pPrv, sal_Bool bNotify )
 {
     if( pPrv )
     {
@@ -174,7 +174,7 @@ void SwFrm::MakeLeftPos( const SwFrm* pUp, const SwFrm* pPrv, BOOL bNotify )
         aFrm.Pos().X() -= 1;
 }
 
-void SwFrm::MakeRightPos( const SwFrm* pUp, const SwFrm* pPrv, BOOL bNotify )
+void SwFrm::MakeRightPos( const SwFrm* pUp, const SwFrm* pPrv, sal_Bool bNotify )
 {
     if( pPrv )
     {
@@ -214,9 +214,9 @@ void SwFrm::SetRightLeftMargins( long nRight, long nLeft)
     Prt().Width( Frm().Width() - nLeft - nRight );
 }
 
-const USHORT nMinVertCellHeight = 1135;
+const sal_uInt16 nMinVertCellHeight = 1135;
 
-/*-----------------11.9.2001 11:11------------------
+/*--------------------------------------------------
  * SwFrm::CheckDirChange(..)
  * checks the layout direction and
  * invalidates the lower frames rekursivly, if necessary.
@@ -224,13 +224,15 @@ const USHORT nMinVertCellHeight = 1135;
 
 void SwFrm::CheckDirChange()
 {
-    BOOL bOldVert = GetVerticalFlag();
-    BOOL bOldRev = IsReverse();
-    BOOL bOldR2L = GetRightToLeftFlag();
-    SetInvalidVert( TRUE );
-    SetInvalidR2L( TRUE );
-    BOOL bChg = bOldR2L != IsRightToLeft();
-    if( ( IsVertical() != bOldVert ) || bChg || IsReverse() != bOldRev )
+    sal_Bool bOldVert = GetVerticalFlag();
+    sal_Bool bOldRev = IsReverse();
+    sal_Bool bOldR2L = GetRightToLeftFlag();
+    SetInvalidVert( sal_True );
+    SetInvalidR2L( sal_True );
+    sal_Bool bChg = bOldR2L != IsRightToLeft();
+    //Badaa: 2008-04-18 * Support for Classical Mongolian Script (SCMS) joint with Jiayanmin
+    sal_Bool bOldVertL2R = IsVertLR();   
+    if( ( IsVertical() != bOldVert ) || bChg || IsReverse() != bOldRev || bOldVertL2R != IsVertLR() )
     {
         InvalidateAll();
         if( IsLayoutFrm() )
@@ -280,7 +282,7 @@ void SwFrm::CheckDirChange()
                 pFrm = pFrm->GetNext();
             }
             if( pCol )
-                pBody->AdjustColumns( pCol, TRUE );
+                pBody->AdjustColumns( pCol, sal_True );
         }
         else if( IsTxtFrm() )
             ((SwTxtFrm*)this)->Prepare( PREP_CLEAR );
@@ -315,7 +317,7 @@ void SwFrm::CheckDirChange()
     }
 }
 
-/*-----------------13.9.2002 11:11------------------
+/*--------------------------------------------------
  * SwFrm::GetFrmAnchorPos(..)
  * returns the position for anchors based on frame direction
  * --------------------------------------------------*/
@@ -324,9 +326,10 @@ void SwFrm::CheckDirChange()
 Point SwFrm::GetFrmAnchorPos( sal_Bool bIgnoreFlysAnchoredAtThisFrame ) const
 {
     Point aAnchor = Frm().Pos();
-    if ( IsVertical() || IsRightToLeft() )
+    //Badaa: 2008-04-18 * Support for Classical Mongolian Script (SCMS) joint with Jiayanmin
+    if ( ( IsVertical() && !IsVertLR() ) || IsRightToLeft() )
         aAnchor.X() += Frm().Width();
-
+    
     if ( IsTxtFrm() )
     {
         SwTwips nBaseOfstForFly =
@@ -360,25 +363,21 @@ Point SwFrm::GetFrmAnchorPos( sal_Bool bIgnoreFlysAnchoredAtThisFrame ) const
 |*
 |*	SwFrm::~SwFrm()
 |*
-|*	Ersterstellung		MA 02. Mar. 94
-|*	Letzte Aenderung	MA 25. Jun. 95
-|*
 |*************************************************************************/
 
-
 SwFrm::~SwFrm()
 {
     // accessible objects for fly and cell frames have been already disposed
     // by the destructors of the derived classes.
     if( IsAccessibleFrm() && !(IsFlyFrm() || IsCellFrm()) && GetDep() )
     {
-        SwRootFrm *pRootFrm = FindRootFrm();
+        SwRootFrm *pRootFrm = getRootFrm();
         if( pRootFrm && pRootFrm->IsAnyShellAccessible() )
         {
             ViewShell *pVSh = pRootFrm->GetCurrShell();
             if( pVSh && pVSh->Imp() )
             {
-                ASSERT( !GetLower(), "Lowers should be dispose already!" );
+                OSL_ENSURE( !GetLower(), "Lowers should be dispose already!" );
                 pVSh->Imp()->DisposeAccessibleFrm( this );
             }
         }
@@ -396,7 +395,7 @@ SwFrm::~SwFrm()
                 SdrObject* pSdrObj = pAnchoredObj->DrawObj();
                 SwDrawContact* pContact =
                         static_cast<SwDrawContact*>(pSdrObj->GetUserCall());
-                ASSERT( pContact,
+                OSL_ENSURE( pContact,
                         "<SwFrm::~SwFrm> - missing contact for drawing object" );
                 if ( pContact )
                 {
@@ -408,17 +407,28 @@ SwFrm::~SwFrm()
             delete pDrawObjs;
     }
 
-#ifdef DBG_UTIL
+#if OSL_DEBUG_LEVEL > 1
     // JP 15.10.2001: for detection of access to deleted frames
     pDrawObjs = (SwSortedObjs*)0x33333333;
 #endif
 }
 
+/*************************************************************************/
+
+const SwFrmFmt * SwLayoutFrm::GetFmt() const
+{ 
+    return static_cast< const SwFlyFrmFmt * >( GetDep() );
+}
+
+SwFrmFmt * SwLayoutFrm::GetFmt()
+{
+    return static_cast< SwFlyFrmFmt * >( GetDep() );
+}
+
+
 /*************************************************************************
 |*
 |*	  SwLayoutFrm::SetFrmFmt()
-|*	  Ersterstellung	MA 22. Apr. 93
-|*	  Letzte Aenderung	MA 02. Nov. 94
 |*
 |*************************************************************************/
 
@@ -430,15 +440,15 @@ void SwLayoutFrm::SetFrmFmt( SwFrmFmt *pNew )
         SwFmtChg aOldFmt( GetFmt() );
         pNew->Add( this );
         SwFmtChg aNewFmt( pNew );
-        Modify( &aOldFmt, &aNewFmt );
+        ModifyNotification( &aOldFmt, &aNewFmt );
     }
 }
 
 /*************************************************************************
 |*                  SwCntntFrm::SwCntntFrm()
 |*************************************************************************/
-SwCntntFrm::SwCntntFrm( SwCntntNode * const pCntnt ) :
-    SwFrm( pCntnt ),
+SwCntntFrm::SwCntntFrm( SwCntntNode * const pCntnt, SwFrm* pSib ) :
+    SwFrm( pCntnt, pSib ),
     SwFlowFrm( (SwFrm&)*this )
 {
 }
@@ -449,11 +459,11 @@ SwCntntFrm::SwCntntFrm( SwCntntNode * const pCntnt ) :
 SwCntntFrm::~SwCntntFrm()
 {
     SwCntntNode* pCNd;
-    if( 0 != ( pCNd = PTR_CAST( SwCntntNode, pRegisteredIn )) &&
+    if( 0 != ( pCNd = PTR_CAST( SwCntntNode, GetRegisteredIn() )) &&
         !pCNd->GetDoc()->IsInDtor() )
     {
         //Bei der Root abmelden wenn ich dort noch im Turbo stehe.
-        SwRootFrm *pRoot = FindRootFrm();
+        SwRootFrm *pRoot = getRootFrm();
         if( pRoot && pRoot->GetTurbo() == this )
         {
             pRoot->DisallowTurbo();
@@ -463,8 +473,8 @@ SwCntntFrm::~SwCntntFrm()
         {
             SwTxtNode *pTxtNd = ((SwTxtFrm*)this)->GetTxtNode();
             const SwFtnIdxs &rFtnIdxs = pCNd->GetDoc()->GetFtnIdxs();
-            USHORT nPos;
-            ULONG nIndex = pCNd->GetIndex();
+            sal_uInt16 nPos;
+            sal_uLong nIndex = pCNd->GetIndex();
             rFtnIdxs.SeekEntry( *pTxtNd, &nPos );
             SwTxtFtn* pTxtFtn;
             if( nPos < rFtnIdxs.Count() )
@@ -479,20 +489,77 @@ SwCntntFrm::~SwCntntFrm()
                 pTxtFtn = rFtnIdxs[ nPos ];
                 if( pTxtFtn->GetTxtNode().GetIndex() > nIndex )
                     break;
-                pTxtFtn->DelFrms();
+                pTxtFtn->DelFrms( this );
                 ++nPos;
             }
         }
     }
 }
 
+void SwCntntFrm::RegisterToNode( SwCntntNode& rNode )
+{
+    rNode.Add( this );
+}
+
+void SwCntntFrm::DelFrms( const SwCntntNode& rNode )
+{
+    SwIterator<SwCntntFrm,SwCntntNode> aIter( rNode );    
+    for( SwCntntFrm* pFrm = aIter.First(); pFrm; pFrm = aIter.Next() )
+    {
+        // --> OD 2005-12-01 #i27138#
+        // notify accessibility paragraphs objects about changed
+        // CONTENT_FLOWS_FROM/_TO relation.
+        // Relation CONTENT_FLOWS_FROM for current next paragraph will change
+        // and relation CONTENT_FLOWS_TO for current previous paragraph will change.
+        if ( pFrm->IsTxtFrm() )
+        {
+            ViewShell* pViewShell( pFrm->getRootFrm()->GetCurrShell() );
+            if ( pViewShell && pViewShell->GetLayout() &&
+                 pViewShell->GetLayout()->IsAnyShellAccessible() )
+            {
+                pViewShell->InvalidateAccessibleParaFlowRelation(
+                            dynamic_cast<SwTxtFrm*>(pFrm->FindNextCnt( true )),
+                            dynamic_cast<SwTxtFrm*>(pFrm->FindPrevCnt( true )) );
+            }
+        }
+        // <--
+        if( pFrm->HasFollow() )
+            pFrm->GetFollow()->_SetIsFollow( pFrm->IsFollow() );
+        if( pFrm->IsFollow() )
+        {
+            SwCntntFrm* pMaster = (SwTxtFrm*)pFrm->FindMaster();
+            pMaster->SetFollow( pFrm->GetFollow() );
+            pFrm->_SetIsFollow( sal_False );
+        }
+        pFrm->SetFollow( 0 );//Damit er nicht auf dumme Gedanken kommt.
+                                //Andernfalls kann es sein, dass ein Follow
+                                //vor seinem Master zerstoert wird, der Master
+                                //greift dann ueber den ungueltigen
+                                //Follow-Pointer auf fremdes Memory zu.
+                                //Die Kette darf hier zerknauscht werden, weil
+                                //sowieso alle zerstoert werden.
+        if( pFrm->GetUpper() && pFrm->IsInFtn() && !pFrm->GetIndNext() &&
+            !pFrm->GetIndPrev() )
+        {
+            SwFtnFrm *pFtn = pFrm->FindFtnFrm();
+            OSL_ENSURE( pFtn, "You promised a FtnFrm?" );
+            SwCntntFrm* pCFrm;
+            if( !pFtn->GetFollow() && !pFtn->GetMaster() &&
+                0 != ( pCFrm = pFtn->GetRefFromAttr()) && pCFrm->IsFollow() )
+            {
+                OSL_ENSURE( pCFrm->IsTxtFrm(), "NoTxtFrm has Footnote?" );
+                ((SwTxtFrm*)pCFrm->FindMaster())->Prepare( PREP_FTN_GONE );
+            }
+        }
+        pFrm->Cut();
+        delete pFrm;
+    }
+}
+
 /*************************************************************************
 |*
 |*	SwLayoutFrm::~SwLayoutFrm
 |*
-|*	Ersterstellung		AK 28-Feb-1991
-|*	Letzte Aenderung	MA 11. Jan. 95
-|*
 |*************************************************************************/
 
 
@@ -522,7 +589,7 @@ SwLayoutFrm::~SwLayoutFrm()
                     SdrObject* pSdrObj = pAnchoredObj->DrawObj();
                     SwDrawContact* pContact =
                             static_cast<SwDrawContact*>(pSdrObj->GetUserCall());
-                    ASSERT( pContact,
+                    OSL_ENSURE( pContact,
                             "<SwFrm::~SwFrm> - missing contact for drawing object" );
                     if ( pContact )
                     {
@@ -555,7 +622,7 @@ SwLayoutFrm::~SwLayoutFrm()
                 SdrObject* pSdrObj = pAnchoredObj->DrawObj();
                 SwDrawContact* pContact =
                         static_cast<SwDrawContact*>(pSdrObj->GetUserCall());
-                ASSERT( pContact,
+                OSL_ENSURE( pContact,
                         "<SwFrm::~SwFrm> - missing contact for drawing object" );
                 if ( pContact )
                 {
@@ -584,9 +651,6 @@ SwLayoutFrm::~SwLayoutFrm()
 |*
 |*	SwFrm::PaintArea()
 |*
-|*	Created		AMA 08/22/2000
-|*	Last change	AMA 08/23/2000
-|*
 |*  The paintarea is the area, in which the content of a frame is allowed
 |*  to be displayed. This region could be larger than the printarea (Prt())
 |*  of the upper, it includes e.g. often the margin of the page.
@@ -598,13 +662,14 @@ const SwRect SwFrm::PaintArea() const
     // NEW TABLES
     // Cell frames may not leave their upper:
     SwRect aRect = IsRowFrm() ? GetUpper()->Frm() : Frm();
-    const BOOL bVert = IsVertical();
-    SwRectFn fnRect = bVert ? fnRectVert : fnRectHori;
+    const sal_Bool bVert = IsVertical();
+    //Badaa: 2008-04-18 * Support for Classical Mongolian Script (SCMS) joint with Jiayanmin
+    SwRectFn fnRect = bVert ? ( IsVertLR() ? fnRectVertL2R : fnRectVert ) : fnRectHori;
     long nRight = (aRect.*fnRect->fnGetRight)();
     long nLeft  = (aRect.*fnRect->fnGetLeft)();
     const SwFrm* pTmp = this;
-    BOOL bLeft = TRUE;
-    BOOL bRight = TRUE;
+    sal_Bool bLeft = sal_True;
+    sal_Bool bRight = sal_True;
     long nRowSpan = 0;
     while( pTmp )
     {
@@ -623,7 +688,7 @@ const SwRect SwFrm::PaintArea() const
             else
                 nTmpRight = (pNxt->Frm().*fnRect->fnGetRight)();
         }
-        ASSERT( pTmp, "PaintArea lost in time and space" );
+        OSL_ENSURE( pTmp, "PaintArea lost in time and space" );
         if( pTmp->IsPageFrm() || pTmp->IsFlyFrm() ||
             pTmp->IsCellFrm() || pTmp->IsRowFrm() || //nobody leaves a table!
             pTmp->IsRootFrm() )
@@ -634,25 +699,25 @@ const SwRect SwFrm::PaintArea() const
                 nRight = nTmpRight;
             if( pTmp->IsPageFrm() || pTmp->IsFlyFrm() || pTmp->IsRootFrm() )
                 break;
-            bLeft = FALSE;
-            bRight = FALSE;
+            bLeft = sal_False;
+            bRight = sal_False;
         }
         else if( pTmp->IsColumnFrm() )  // nobody enters neightbour columns
         {
-            BOOL bR2L = pTmp->IsRightToLeft();
+            sal_Bool bR2L = pTmp->IsRightToLeft();
             // the first column has _no_ influence to the left range
             if( bR2L ? pTmp->GetNext() : pTmp->GetPrev() )
             {
                 if( bLeft || nLeft < nTmpLeft )
                     nLeft = nTmpLeft;
-                bLeft = FALSE;
+                bLeft = sal_False;
             }
              // the last column has _no_ influence to the right range
             if( bR2L ? pTmp->GetPrev() : pTmp->GetNext() )
             {
                 if( bRight || nTmpRight < nRight )
                     nRight = nTmpRight;
-                bRight = FALSE;
+                bRight = sal_False;
             }
         }
         else if( bVert && pTmp->IsBodyFrm() )
@@ -666,14 +731,14 @@ const SwRect SwFrm::PaintArea() const
             if( pTmp->GetPrev() && ( bLeft || nLeft < nTmpLeft ) )
             {
                 nLeft = nTmpLeft;
-                bLeft = FALSE;
+                bLeft = sal_False;
             }
             if( pTmp->GetNext() &&
                 ( pTmp->GetNext()->IsFooterFrm() || pTmp->GetNext()->GetNext() )
                 && ( bRight || nTmpRight < nRight ) )
             {
                 nRight = nTmpRight;
-                bRight = FALSE;
+                bRight = sal_False;
             }
         }
         pTmp = pTmp->GetUpper();
@@ -687,18 +752,16 @@ const SwRect SwFrm::PaintArea() const
 |*
 |*	SwFrm::UnionFrm()
 |*
-|*	Created		AMA 08/22/2000
-|*	Last change	AMA 08/23/2000
-|*
 |*  The unionframe is the framearea (Frm()) of a frame expanded by the
 |*  printarea, if there's a negative margin at the left or right side.
 |*
 |*************************************************************************/
 
-const SwRect SwFrm::UnionFrm( BOOL bBorder ) const
+const SwRect SwFrm::UnionFrm( sal_Bool bBorder ) const
 {
-    BOOL bVert = IsVertical();
-    SwRectFn fnRect = bVert ? fnRectVert : fnRectHori;
+    sal_Bool bVert = IsVertical();
+    //Badaa: 2008-04-18 * Support for Classical Mongolian Script (SCMS) joint with Jiayanmin
+    SwRectFn fnRect = bVert ? ( IsVertLR() ? fnRectVertL2R : fnRectVert ) : fnRectHori;
     long nLeft = (Frm().*fnRect->fnGetLeft)();
     long nWidth = (Frm().*fnRect->fnGetWidth)();
     long nPrtLeft = (Prt().*fnRect->fnGetLeft)();
@@ -748,3 +811,4 @@ const SwRect SwFrm::UnionFrm( BOOL bBorder ) const
 
 
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
