@@ -50,7 +50,6 @@
 #include "txtfly.hxx"     // SwTxtFly
 #include "txtpaint.hxx"   // SwSaveClip
 #include "txtatr.hxx"     // SwTxtFlyCnt
-#include "txtcfg.hxx"
 #include "notxtfrm.hxx"
 #include "flyfrms.hxx"
 #include "fmtcnct.hxx"  // SwFmtChain
@@ -74,20 +73,12 @@
 #include <IDocumentDrawModelAccess.hxx>
 #include <IDocumentLayoutAccess.hxx>
 #include <IDocumentSettingAccess.hxx>
-#include <svx/obj3d.hxx>
-#include <editeng/txtrange.hxx>
-#include <editeng/lrspitem.hxx>
-#include <editeng/ulspitem.hxx>
-#include <editeng/lspcitem.hxx>
 #include <svx/svdoedge.hxx>
 #include "doc.hxx"
 
 #if OSL_DEBUG_LEVEL > 1
 #include "viewopt.hxx"	// SwViewOptions, nur zum Testen (Test2)
-#endif
-
-#ifdef VERT_DISTANCE
-#include <math.h>
+#include "doc.hxx"
 #endif
 
 
@@ -547,7 +538,7 @@ void SwTxtFormatter::CalcFlyWidth( SwTxtFormatInfo &rInf )
         if( bForced )
         {
             pCurr->SetForcedLeftMargin( sal_True );
-            rInf.ForcedLeftMargin( (USHORT)aInter.Width() );
+            rInf.ForcedLeftMargin( (sal_uInt16)aInter.Width() );
         }
 
         if( bFullLine )
@@ -620,7 +611,7 @@ void SwTxtFormatter::CalcFlyWidth( SwTxtFormatInfo &rInf )
                                     (pPageFrm->*fnRect->fnGetPrtLeft)();
 
             const SwDoc *pDoc = rInf.GetTxtFrm()->GetNode()->GetDoc();
-            const USHORT nGridWidth = GETGRIDWIDTH( pGrid, pDoc);	//for textgrid refactor
+            const sal_uInt16 nGridWidth = GETGRIDWIDTH( pGrid, pDoc);	//for textgrid refactor
 
             SwTwips nStartX = GetLeftMargin();
             if ( bVert )
@@ -633,11 +624,11 @@ void SwTxtFormatter::CalcFlyWidth( SwTxtFormatInfo &rInf )
             const SwTwips nOfst = nStartX - nGridOrigin;
             const SwTwips nTmpWidth = rInf.Width() + nOfst;
 
-            const ULONG i = nTmpWidth / nGridWidth + 1;
+            const sal_uLong i = nTmpWidth / nGridWidth + 1;
 
             const long nNewWidth = ( i - 1 ) * nGridWidth - nOfst;
             if ( nNewWidth > 0 )
-                rInf.Width( (USHORT)nNewWidth );
+                rInf.Width( (sal_uInt16)nNewWidth );
             else
                 rInf.Width( 0 );
         }
@@ -688,7 +679,7 @@ SwFlyCntPortion *SwTxtFormatter::NewFlyCntPortion( SwTxtFormatInfo &rInf,
                                       pFly->GetRefPoint().Y() );
 
     if ( bUseFlyAscent )
-         nAscent = static_cast<USHORT>( Abs( int( bTxtFrmVertical ?
+         nAscent = static_cast<sal_uInt16>( Abs( int( bTxtFrmVertical ?
                                                   pFly->GetRelPos().X() :
                                                   pFly->GetRelPos().Y() ) ) );
 
@@ -755,12 +746,9 @@ SwFlyCntPortion *SwTxtFormatter::NewFlyCntPortion( SwTxtFormatInfo &rInf,
 SwTxtFly::SwTxtFly( const SwTxtFly& rTxtFly )
 {
     pPage = rTxtFly.pPage;
-    // --> OD 2006-08-15 #i68520#
     mpCurrAnchoredObj = rTxtFly.mpCurrAnchoredObj;
-    // <--
     pCurrFrm = rTxtFly.pCurrFrm;
     pMaster = rTxtFly.pMaster;
-    // --> OD 2006-08-15 #i68520#
     if( rTxtFly.mpAnchoredObjList )
     {
         mpAnchoredObjList = new SwAnchoredObjList( *(rTxtFly.mpAnchoredObjList) );
@@ -769,11 +757,16 @@ SwTxtFly::SwTxtFly( const SwTxtFly& rTxtFly )
     {
         mpAnchoredObjList = NULL;
     }
-    // <--
 
     bOn = rTxtFly.bOn;
     bLeftSide = rTxtFly.bLeftSide;
     bTopRule = rTxtFly.bTopRule;
+    nMinBottom = rTxtFly.nMinBottom;
+    nNextTop = rTxtFly.nNextTop;
+    nIndex = rTxtFly.nIndex;
+    mbIgnoreCurrentFrame = rTxtFly.mbIgnoreCurrentFrame;
+    mbIgnoreContour = rTxtFly.mbIgnoreContour;
+    mbIgnoreObjsInHeaderFooter = rTxtFly.mbIgnoreObjsInHeaderFooter;
 }
 
 void SwTxtFly::CtorInitTxtFly( const SwTxtFrm *pFrm )
@@ -902,7 +895,7 @@ sal_Bool SwTxtFly::IsAnyObj( const SwRect &rRect ) const
 const SwCntntFrm* SwTxtFly::_GetMaster()
 {
     pMaster = pCurrFrm;
-    while( pMaster->IsFollow() )
+    while( pMaster && pMaster->IsFollow() )
         pMaster = (SwCntntFrm*)pMaster->FindMaster();
     return pMaster;
 }
@@ -952,7 +945,7 @@ sal_Bool SwTxtFly::DrawTextOpaque( SwDrawTextInfo &rInf )
 
     sal_Bool bOpaque = sal_False;
     // --> OD 2006-08-15 #i68520#
-    const UINT32 nCurrOrd = mpCurrAnchoredObj
+    const sal_uInt32 nCurrOrd = mpCurrAnchoredObj
                             ? mpCurrAnchoredObj->GetDrawObj()->GetOrdNum()
                             : SAL_MAX_UINT32;
     // <--
@@ -963,7 +956,7 @@ sal_Bool SwTxtFly::DrawTextOpaque( SwDrawTextInfo &rInf )
     if ( bOn && nCount > 0 )
     // <--
     {
-        MSHORT nHellId = pPage->GetShell()->getIDocumentDrawModelAccess()->GetHellId();
+        MSHORT nHellId = pPage->getRootFrm()->GetCurrShell()->getIDocumentDrawModelAccess()->GetHellId();
         for( MSHORT i = 0; i < nCount; ++i )
         {
             // --> OD 2006-08-15 #i68520#
@@ -1068,7 +1061,7 @@ void SwTxtFly::DrawFlyRect( OutputDevice* pOut, const SwRect &rRect,
     if ( bOn && nCount > 0 )
     // <--
     {
-        MSHORT nHellId = pPage->GetShell()->getIDocumentDrawModelAccess()->GetHellId();
+        MSHORT nHellId = pPage->getRootFrm()->GetCurrShell()->getIDocumentDrawModelAccess()->GetHellId();
         for( MSHORT i = 0; i < nCount; ++i )
         {
             // --> OD 2006-08-15 #i68520#
@@ -1107,7 +1100,7 @@ void SwTxtFly::DrawFlyRect( OutputDevice* pOut, const SwRect &rRect,
                     SwRect aFly( pAnchoredObjTmp->GetObjRect() );
                     // <--
                     // OD 24.01.2003 #106593#
-                    ::SwAlignRect( aFly, pPage->GetShell() );
+                    ::SwAlignRect( aFly, pPage->getRootFrm()->GetCurrShell() );
                     if( aFly.Width() > 0 && aFly.Height() > 0 )
                         aRegion -= aFly;
                 }
@@ -1147,8 +1140,8 @@ sal_Bool SwTxtFly::GetTop( const SwAnchoredObject* _pAnchoredObj,
         // #102344# Ignore connectors which have one or more connections
         if(pNew && pNew->ISA(SdrEdgeObj))
         {
-            if(((SdrEdgeObj*)pNew)->GetConnectedNode(TRUE)
-                || ((SdrEdgeObj*)pNew)->GetConnectedNode(FALSE))
+            if(((SdrEdgeObj*)pNew)->GetConnectedNode(sal_True)
+                || ((SdrEdgeObj*)pNew)->GetConnectedNode(sal_False))
             {
                 return sal_False;
             }
@@ -1168,7 +1161,7 @@ sal_Bool SwTxtFly::GetTop( const SwAnchoredObject* _pAnchoredObj,
                 if ( bInFooterOrHeader )
                 {
                     SwFmtVertOrient aVert( rFrmFmt.GetVertOrient() );
-                    BOOL bVertPrt = aVert.GetRelationOrient() == text::RelOrientation::PRINT_AREA ||
+                    sal_Bool bVertPrt = aVert.GetRelationOrient() == text::RelOrientation::PRINT_AREA ||
                             aVert.GetRelationOrient() == text::RelOrientation::PAGE_PRINT_AREA;
                     if( bVertPrt )
                         return sal_False;
@@ -1338,7 +1331,7 @@ sal_Bool SwTxtFly::GetTop( const SwAnchoredObject* _pAnchoredObj,
 
                 // Compare indices:
                 // Den Index des anderen erhalten wir immer ueber das Ankerattr.
-                ULONG nTmpIndex = rNewA.GetCntntAnchor()->nNode.GetIndex();
+                sal_uLong nTmpIndex = rNewA.GetCntntAnchor()->nNode.GetIndex();
                 // Jetzt wird noch ueberprueft, ob der aktuelle Absatz vor dem
                 // Anker des verdraengenden Objekts im Text steht, dann wird
                 // nicht ausgewichen.
@@ -1621,7 +1614,9 @@ SwAnchoredObjList* SwTxtFly::InitAnchoredObjList()
 SwTwips SwTxtFly::CalcMinBottom() const
 {
     SwTwips nRet = 0;
-    const SwSortedObjs *pDrawObj = GetMaster()->GetDrawObjs();
+    const SwCntntFrm *pLclMaster = GetMaster();
+    OSL_ENSURE(pLclMaster, "SwTxtFly without master");
+    const SwSortedObjs *pDrawObj = pLclMaster ? pLclMaster->GetDrawObjs() : NULL;
     const sal_uInt32 nCount = pDrawObj ? pDrawObj->Count() : 0;
     if( nCount )
     {
@@ -1797,7 +1792,7 @@ const SwRect SwContourCache::ContourRect( const SwFmt* pFmt,
         pSdrObj[ 0 ] = pObj; // Wg. #37347 darf das Object erst nach dem
                              // GetContour() eingetragen werden.
         pTextRanger[ 0 ] = new TextRanger( aPolyPolygon, pPolyPolygon, 20,
-            (USHORT)rLRSpace.GetLeft(), (USHORT)rLRSpace.GetRight(),
+            (sal_uInt16)rLRSpace.GetLeft(), (sal_uInt16)rLRSpace.GetRight(),
             pFmt->GetSurround().IsOutside(), sal_False, pFrm->IsVertical() );
         pTextRanger[ 0 ]->SetUpper( rULSpace.GetUpper() );
         pTextRanger[ 0 ]->SetLower( rULSpace.GetLower() );
@@ -1805,11 +1800,11 @@ const SwRect SwContourCache::ContourRect( const SwFmt* pFmt,
         delete pPolyPolygon;
         // UPPER_LOWER_TEST
 #if OSL_DEBUG_LEVEL > 1
-        const SwRootFrm* pTmpRootFrm = pFmt->getIDocumentLayoutAccess()->GetRootFrm();
-        if( pTmpRootFrm->GetCurrShell() )
+        const ViewShell* pTmpViewShell = pFmt->GetDoc()->GetCurrentViewShell();
+        if( pTmpViewShell )
         {
-            sal_Bool bT2 = pTmpRootFrm->GetCurrShell()->GetViewOptions()->IsTest2();
-            sal_Bool bT6 = pTmpRootFrm->GetCurrShell()->GetViewOptions()->IsTest6();
+            sal_Bool bT2 = pTmpViewShell->GetViewOptions()->IsTest2();
+            sal_Bool bT6 = pTmpViewShell->GetViewOptions()->IsTest6();
             if( bT2 || bT6 )
             {
                 if( bT2 )
@@ -1842,10 +1837,10 @@ const SwRect SwContourCache::ContourRect( const SwFmt* pFmt,
 
     Range aRange( Min( nTmpTop, nTmpBottom ), Max( nTmpTop, nTmpBottom ) );
 
-    SvLongs *pTmp = pTextRanger[ 0 ]->GetTextRanges( aRange );
+    LongDqPtr pTmp = pTextRanger[ 0 ]->GetTextRanges( aRange );
 
     MSHORT nCount;
-    if( 0 != ( nCount = pTmp->Count() ) )
+    if( 0 != ( nCount = pTmp->size() ) )
     {
         MSHORT nIdx = 0;
         while( nIdx < nCount && (*pTmp)[ nIdx ] < nXPos )
@@ -1899,7 +1894,6 @@ void SwContourCache::ShowContour( OutputDevice* pOut, const SdrObject* pObj,
                 pOut->SetLineColor( rClosedColor );
             pOut->DrawPolygon( rPol );
         }
-#if OSL_DEBUG_LEVEL > 1
         static KSHORT nRadius = 0;
         if( nRadius )
         {
@@ -1919,7 +1913,6 @@ void SwContourCache::ShowContour( OutputDevice* pOut, const SdrObject* pObj,
                 }
             }
         }
-#endif
     }
 }
 #endif
@@ -1933,7 +1926,7 @@ void SwContourCache::ShowContour( OutputDevice* pOut, const SdrObject* pObj,
 void SwTxtFly::ShowContour( OutputDevice* pOut )
 {
     MSHORT nFlyCount;
-    if( bOn && ( 0 != ( nFlyCount = static_cast<USHORT>(GetAnchoredObjList()->size() ) ) ) )
+    if( bOn && ( 0 != ( nFlyCount = static_cast<sal_uInt16>(GetAnchoredObjList()->size() ) ) ) )
     {
         Color aRedColor( COL_LIGHTRED );
         Color aGreenColor( COL_LIGHTGREEN );
