@@ -1,7 +1,9 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
+ * Copyright 2000, 2010 Oracle and/or its affiliates.
  * Copyright 2010 Miklos Vajna.
  *
  * OpenOffice.org - a multi-platform office productivity suite
@@ -28,6 +30,7 @@
 #include "rtfsdrexport.hxx"
 #include "rtfexport.hxx"
 #include "writerhelper.hxx"
+#include "rtfattributeoutput.hxx"
 
 #include <com/sun/star/i18n/ScriptType.hdl>
 #include <osl/diagnose.h>
@@ -87,7 +90,7 @@ RtfSdrExport::~RtfSdrExport()
     delete[] m_pShapeTypeWritten, m_pShapeTypeWritten = NULL;
 }
 
-void RtfSdrExport::OpenContainer( UINT16 nEscherContainer, int nRecInstance )
+void RtfSdrExport::OpenContainer( sal_uInt16 nEscherContainer, int nRecInstance )
 {
     OSL_TRACE("%s", OSL_THIS_FUNC);
 
@@ -120,7 +123,7 @@ void RtfSdrExport::CloseContainer()
     EscherEx::CloseContainer();
 }
 
-UINT32 RtfSdrExport::EnterGroup( const String& /*rShapeName*/, const Rectangle* /*pRect*/ )
+sal_uInt32 RtfSdrExport::EnterGroup( const String& /*rShapeName*/, const Rectangle* /*pRect*/ )
 {
     OSL_TRACE("%s", OSL_THIS_FUNC);
 
@@ -134,7 +137,7 @@ void RtfSdrExport::LeaveGroup()
     /* noop */
 }
 
-void RtfSdrExport::AddShape( UINT32 nShapeType, UINT32 nShapeFlags, UINT32 /*nShapeId*/ )
+void RtfSdrExport::AddShape( sal_uInt32 nShapeType, sal_uInt32 nShapeFlags, sal_uInt32 /*nShapeId*/ )
 {
     OSL_TRACE("%s", OSL_THIS_FUNC);
 
@@ -221,8 +224,9 @@ void RtfSdrExport::Commit( EscherPropertyContainer& rProps, const Rectangle& rRe
                     m_aShapeProps.insert(std::pair<OString,OString>(OString("fNoFillHitTest"), OString::valueOf(sal_Int32(1))));
                 break;
             case ESCHER_Prop_fNoLineDrawDash:
-                if (it->nPropValue)
-                    m_aShapeProps.insert(std::pair<OString,OString>(OString("fNoLineDrawDash"), OString::valueOf(sal_Int32(1))));
+                // for some reason the value is set to 0x90000 if lines are switched off
+                if( it->nPropValue == 0x90000 )
+                    m_aShapeProps.insert(std::pair<OString,OString>(OString("fLine"), OString::valueOf(sal_Int32(0))));
                 break;
             case ESCHER_Prop_lineColor:
                 m_aShapeProps.insert(std::pair<OString,OString>(OString("lineColor"), OString::valueOf(sal_Int32(it->nPropValue))));
@@ -446,6 +450,13 @@ void RtfSdrExport::AddShapeAttribute( sal_Int32 /*nAttribute*/, const rtl::OStri
 
 extern const char* pShapeTypes[];
 
+void lcl_AppendSP( ::rtl::OStringBuffer& rRunText, const char cName[], const ::rtl::OString& rValue)
+{
+    rRunText.append('{').append(OOO_STRING_SVTOOLS_RTF_SP)
+        .append('{').append(OOO_STRING_SVTOOLS_RTF_SN " ").append(cName).append('}')
+        .append('{').append(OOO_STRING_SVTOOLS_RTF_SV " ").append(rValue).append('}')
+        .append('}');
+}
 sal_Int32 RtfSdrExport::StartShape()
 {
     OSL_TRACE("%s", OSL_THIS_FUNC);
@@ -464,11 +475,11 @@ sal_Int32 RtfSdrExport::StartShape()
     // Ignore \shpbypage, \shpbymargin, and \shpbycolumn, in favor of the posrelh property.
     m_rAttrOutput.RunText().append(OOO_STRING_SVTOOLS_RTF_SHPBYIGNORE);
 
-    for(std::map<OString,OString>::reverse_iterator i = m_aShapeProps.rbegin(); i != m_aShapeProps.rend(); i++)
-        m_rAttrOutput.RunText().append('{').append(OOO_STRING_SVTOOLS_RTF_SP)
-            .append('{').append(OOO_STRING_SVTOOLS_RTF_SN " ").append((*i).first).append('}')
-            .append('{').append(OOO_STRING_SVTOOLS_RTF_SV " ").append((*i).second).append('}')
-            .append('}');
+    for(std::map<OString,OString>::reverse_iterator i = m_aShapeProps.rbegin(); i != m_aShapeProps.rend(); ++i)
+        lcl_AppendSP(m_rAttrOutput.RunText(), (*i).first, (*i).second );
+    
+    lcl_AppendSP(m_rAttrOutput.RunText(), "wzDescription", RtfExport::OutString( m_pSdrObject->GetDescription(), m_rExport.eCurrentEncoding));
+    lcl_AppendSP(m_rAttrOutput.RunText(), "wzName", RtfExport::OutString( m_pSdrObject->GetTitle(), m_rExport.eCurrentEncoding));
 
     // now check if we have some text
     const SdrTextObj* pTxtObj = PTR_CAST(SdrTextObj, m_pSdrObject);
@@ -511,10 +522,10 @@ void RtfSdrExport::WriteOutliner(const OutlinerParaObject& rParaObj)
     const EditTextObject& rEditObj = rParaObj.GetTextObject();
     MSWord_SdrAttrIter aAttrIter( m_rExport, rEditObj, TXT_HFTXTBOX );
 
-    USHORT nPara = rEditObj.GetParagraphCount();
+    sal_uInt16 nPara = rEditObj.GetParagraphCount();
 
     m_rAttrOutput.RunText().append('{').append(OOO_STRING_SVTOOLS_RTF_SHPTXT).append(' ');
-    for (USHORT n = 0; n < nPara; ++n)
+    for (sal_uInt16 n = 0; n < nPara; ++n)
     {
         if( n )
             aAttrIter.NextPara( n );
@@ -568,10 +579,10 @@ void RtfSdrExport::EndShape( sal_Int32 nShapeElement )
     }
 }
 
-UINT32 RtfSdrExport::AddSdrObject( const SdrObject& rObj )
+sal_uInt32 RtfSdrExport::AddSdrObject( const SdrObject& rObj )
 {
     m_pSdrObject = &rObj;
     return EscherEx::AddSdrObject(rObj);
 }
 
-/* vi:set shiftwidth=4 expandtab: */
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
