@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -28,11 +29,7 @@
 // MARKER(update_precomp.py): autogen include statement, do not remove
 #include "precompiled_sw.hxx"
 
-
-#if STLPORT_VERSION>=321
 #include <cstdarg>
-#endif
-
 
 #include <hintids.hxx>
 
@@ -78,12 +75,8 @@
 #include <pagedesc.hxx>
 #include <poolfmt.hxx>
 
-#ifndef _APP_HRC
 #include <app.hrc>
-#endif
-#ifndef _POOLFMT_HRC
 #include <poolfmt.hrc>
-#endif
 #include "swabstdlg.hxx"
 #include "envelp.hrc"
 #include <misc.hrc>
@@ -93,12 +86,10 @@
 using namespace ::com::sun::star;
 using ::rtl::OUString;
 
-// steht im appenv.cxx
+// is in appenv.cxx
 extern String InsertLabEnvText( SwWrtShell& , SwFldMgr& , const String& );
 
-const char __FAR_DATA MASTER_LABEL[] = "MasterLabel";
-
-// --------------------------------------------------------------------------
+const char MASTER_LABEL[] = "MasterLabel";
 
 const SwFrmFmt *lcl_InsertBCText( SwWrtShell& rSh, const SwLabItem& rItem,
                         SwFrmFmt &rFmt,
@@ -117,18 +108,17 @@ const SwFrmFmt *lcl_InsertBCText( SwWrtShell& rSh, const SwLabItem& rItem,
         aSet.Put(SwFmtVertOrient(rItem.lUpper + nRow * rItem.lVDist,
                                                     text::VertOrientation::NONE, text::RelOrientation::PAGE_FRAME ));
     }
-    const SwFrmFmt *pFmt = rSh.NewFlyFrm(aSet, sal_True,  &rFmt );	// Fly einfuegen
-    ASSERT( pFmt, "Fly not inserted" );
+    const SwFrmFmt *pFmt = rSh.NewFlyFrm(aSet, sal_True,  &rFmt );	// Insert Fly
+    OSL_ENSURE( pFmt, "Fly not inserted" );
 
-    rSh.UnSelectFrm();	//Rahmen wurde automatisch selektiert
+    rSh.UnSelectFrm();	//Frame was selected automatically
 
     rSh.SetTxtFmtColl( rSh.GetTxtCollFromPool( RES_POOLCOLL_STANDARD ) );
 
-    //
     if(!rItem.bSynchron || !(nCol|nRow))
     {
         SwAbstractDialogFactory* pFact = SwAbstractDialogFactory::Create();
-        DBG_ASSERT(pFact, "Dialogdiet fail!");
+        OSL_ENSURE(pFact, "Dialogdiet fail!");
         ::GlossarySetActGroup fnSetActGroup = pFact->SetGlossaryActGroupFunc( DLG_RENAME_GLOS );
         if ( fnSetActGroup )
             (*fnSetActGroup)( rItem.sGlossaryGroup );
@@ -157,14 +147,14 @@ const SwFrmFmt *lcl_InsertLabText( SwWrtShell& rSh, const SwLabItem& rItem,
         aSet.Put(SwFmtVertOrient(rItem.lUpper + nRow * rItem.lVDist,
                                                     text::VertOrientation::NONE, text::RelOrientation::PAGE_FRAME ));
     }
-    const SwFrmFmt *pFmt = rSh.NewFlyFrm(aSet, sal_True,  &rFmt );	// Fly einfuegen
-    ASSERT( pFmt, "Fly not inserted" );
+    const SwFrmFmt *pFmt = rSh.NewFlyFrm(aSet, sal_True,  &rFmt );	// Insert Fly
+    OSL_ENSURE( pFmt, "Fly not inserted" );
 
-    rSh.UnSelectFrm();	//Rahmen wurde automatisch selektiert
+    rSh.UnSelectFrm();	//Frame was selected automatically
 
     rSh.SetTxtFmtColl( rSh.GetTxtCollFromPool( RES_POOLCOLL_STANDARD ) );
 
-    // Ggf. "Naechster Datensatz"
+    // If applicable "next dataset"
     String sDBName;
     if( (!rItem.bSynchron || !(nCol|nRow)) && (sDBName = InsertLabEnvText( rSh, rFldMgr, rItem.aWriting )).Len() && !bLast )
     {
@@ -176,43 +166,41 @@ const SwFrmFmt *lcl_InsertLabText( SwWrtShell& rSh, const SwLabItem& rItem,
     return pFmt;
 }
 
-// ----------------------------------------------------------------------------
-
 
 void SwModule::InsertLab(SfxRequest& rReq, sal_Bool bLabel)
 {
-static sal_uInt16 nLabelTitleNo = 0;
-static sal_uInt16 nBCTitleNo = 0;
+    static sal_uInt16 nLabelTitleNo = 0;
+    static sal_uInt16 nBCTitleNo = 0;
 
-    // DB-Manager anlegen
+    // Create DB-Manager
     SwNewDBMgr* pNewDBMgr = new SwNewDBMgr;
 
-    // SwLabItem aus Config lesen
+    // Read SwLabItem from Config
     SwLabCfgItem aLabCfg(bLabel);
 
-    // Dialog hochfahren
+    // Move up Dialog
     SfxItemSet aSet( GetPool(), FN_LABEL, FN_LABEL, 0 );
     aSet.Put( aLabCfg.GetItem() );
 
     SwAbstractDialogFactory* pDialogFactory = SwAbstractDialogFactory::Create();
-    DBG_ASSERT(pDialogFactory, "SwAbstractDialogFactory fail!");
+    OSL_ENSURE(pDialogFactory, "SwAbstractDialogFactory fail!");
 
-    AbstarctSwLabDlg* pDlg = pDialogFactory->CreateSwLabDlg( 0, aSet, pNewDBMgr, bLabel, DLG_LAB );
-    DBG_ASSERT(pDlg, "Dialogdiet fail!");
+    AbstractSwLabDlg* pDlg = pDialogFactory->CreateSwLabDlg( 0, aSet, pNewDBMgr, bLabel, DLG_LAB );
+    OSL_ENSURE(pDlg, "Dialogdiet fail!");
 
     if ( RET_OK == pDlg->Execute() )
     {
-        // Dialog auslesen, Item in Config speichern
+        // Read dialog, store item in config
         const SwLabItem& rItem = (const SwLabItem&) pDlg->
                                             GetOutputItemSet()->Get(FN_LABEL);
         aLabCfg.GetItem() = rItem;
         aLabCfg.Commit();
 
-        // Neues Dokument erzeugen.
-        SfxObjectShellRef xDocSh( new SwDocShell( SFX_CREATE_MODE_STANDARD));
+        // Create new document
+        SfxObjectShellLock xDocSh( new SwDocShell( SFX_CREATE_MODE_STANDARD));
         xDocSh->DoInitNew( 0 );
 
-        // Drucker
+        // Printer
         Printer *pPrt = pDlg->GetPrt();
         if (pPrt)
         {
@@ -223,9 +211,9 @@ static sal_uInt16 nBCTitleNo = 0;
         SfxViewFrame* pViewFrame = SfxViewFrame::DisplayNewDocument( *xDocSh, rReq );
 
         SwView      *pNewView = (SwView*) pViewFrame->GetViewShell();
-        pNewView->AttrChangedNotify( &pNewView->GetWrtShell() );//Damit SelectShell gerufen wird.
+        pNewView->AttrChangedNotify( &pNewView->GetWrtShell() );// So that SelectShell is being called.
 
-        // Dokumenttitel setzen
+        // Set document title
         String aTmp;
         if(bLabel)
         {
@@ -241,9 +229,9 @@ static sal_uInt16 nBCTitleNo = 0;
 
         pViewFrame->GetFrame().Appear();
 
-        // Shell ermitteln
+        // Determine Shell
         SwWrtShell *pSh = pNewView->GetWrtShellPtr();
-        ASSERT( pSh, "missing WrtShell" );
+        OSL_ENSURE( pSh, "missing WrtShell" );
 
         {	// block for locks the dispatcher!!
 
@@ -254,12 +242,12 @@ static sal_uInt16 nBCTitleNo = 0;
             pSh->DoUndo( sal_False );
             pSh->StartAllAction();
 
-            pSh->SetNewDoc();		// Performanceprobleme vermeiden
+            pSh->SetNewDoc();		// Avoid performance problems
 
             SwPageDesc aDesc = pSh->GetPageDesc( 0 );
             SwFrmFmt&  rFmt  = aDesc.GetMaster();
 
-            // Raender
+            // Borders
             SvxLRSpaceItem aLRMargin( RES_LR_SPACE );
             SvxULSpaceItem aULMargin( RES_UL_SPACE );
             aLRMargin.SetLeft ((sal_uInt16) rItem.lLeft );
@@ -269,26 +257,30 @@ static sal_uInt16 nBCTitleNo = 0;
             rFmt.SetFmtAttr(aLRMargin);
             rFmt.SetFmtAttr(aULMargin);
 
-            // Kopf- und Fusszeilen
+            // Header and footer
             rFmt.SetFmtAttr(SwFmtHeader(sal_Bool(sal_False)));
             aDesc.ChgHeaderShare(sal_False);
             rFmt.SetFmtAttr(SwFmtFooter(sal_Bool(sal_False)));
             aDesc.ChgFooterShare(sal_False);
 
 
-            aDesc.SetUseOn(nsUseOnPage::PD_ALL);				// Seitennumerierung
+            aDesc.SetUseOn(nsUseOnPage::PD_ALL);				// Site numbering
 
-            // Einstellen der Seitengroesse
-            rFmt.SetFmtAttr(SwFmtFrmSize(ATT_FIX_SIZE,
-                                        rItem.lLeft  + rItem.nCols * rItem.lHDist + MINLAY,
-                                        rItem.lUpper + rItem.nRows * rItem.lVDist + MINLAY));
+            // fix (fdo36874) revised page size calculation
+            // Set page size
+            long lPgWidth, lPgHeight;
+            lPgWidth = (((rItem.lLeft  + (rItem.nCols - 1) * rItem.lHDist + rItem.lWidth + rItem.lLeft) > MINLAY) ?
+                (rItem.lLeft  + (rItem.nCols - 1) * rItem.lHDist + rItem.lWidth + rItem.lLeft) : MINLAY);
+            lPgHeight = (((rItem.lUpper + (rItem.nRows - 1) * rItem.lVDist + rItem.lHeight + rItem.lUpper) > MINLAY) ?
+                (rItem.lUpper + (rItem.nRows - 1) * rItem.lVDist + rItem.lHeight + rItem.lUpper) : MINLAY);
+            rFmt.SetFmtAttr( SwFmtFrmSize( ATT_FIX_SIZE, lPgWidth, lPgHeight ));
 
-            // Numerierungsart
+            // Numbering type
             SvxNumberType aType;
             aType.SetNumberingType(SVX_NUM_NUMBER_NONE);
             aDesc.SetNumType( aType );
 
-            // Folgevorlage
+            // Followup template
             const SwPageDesc &rFollow = pSh->GetPageDesc( pSh->GetCurPageDesc() );
             aDesc.SetFollow( &rFollow );
 
@@ -297,23 +289,22 @@ static sal_uInt16 nBCTitleNo = 0;
             aItem.SetValue((sal_Int8)pPrt->GetPaperBin());
             rFmt.SetFmtAttr(aItem);
 
-            //determine orientation by calculating the width and height of the resulting page
+            // Determine orientation by calculating the width and height of the resulting page
             const int nResultWidth = rItem.lHDist * (rItem.nCols - 1) + rItem.lWidth + rItem.lLeft;
             const int nResultHeight = rItem.lVDist * (rItem.nRows - 1) + rItem.lHeight + rItem.lUpper;
             aDesc.SetLandscape(nResultWidth > nResultHeight);
 
             pSh->ChgPageDesc( 0, aDesc );
 
-            // Rahmen einfuegen
+            // Insert frame
             SwFldMgr*		 pFldMgr = new SwFldMgr;
             pFldMgr->SetEvalExpFlds(sal_False);
 
-            //fix(24446): Damit der Text der Ettiketten nicht im unbedruckbaren
-            //Bereich landet stellen wir entsprechende Raender ein. Um das Handling
-            //so Optimal wie moeglich zu halten stellen wir zunaechst an der
-            //aktuellen Absatzvorlage keinen Rand als hartes Attribut ein (Damit die
-            //Formatierung wg. der Zeichengeb. Rahmen passt. Dann stellen wir die
-            //Standarabsatzvorlage anhand des unbedruckbaren Bereiches ein.
+            //fix(24446): To avoid that labels end up in unprintable area, we set
+            //borders accordingly. To keep the handling as good as possible, we
+            //don't set any border as hard attribute at the current paragraph template
+            //(so that formating works, because of character-bound borders). Then
+            //we set the default paragraph template using the unprintable area.
             const long nMin = pPrt->GetPageOffset().X() - rItem.lLeft;
             if ( nMin > 0 )
             {
@@ -325,7 +316,7 @@ static sal_uInt16 nBCTitleNo = 0;
                 pStandard->SetFmtAttr( aLR );
             }
 
-            // Rahmenvorlage vorbereiten
+            // Prepare border template
             SwFrmFmt* pFmt = pSh->GetFrmFmtFromPool( RES_POOLFRM_LABEL );
             SwFmtFrmSize aFrmSize(	ATT_FIX_SIZE,
                                     rItem.lHDist - (rItem.lHDist-rItem.lWidth),
@@ -392,15 +383,15 @@ static sal_uInt16 nBCTitleNo = 0;
                             sLinkName += String::CreateFromAscii(MASTER_LABEL);
                             aSect.SetLinkFileName(sLinkName);
                             aSect.SetProtectFlag(true);
-                            pSh->Insert(aDotStr);	// Dummytext zum Zuweisen der Section
+                            pSh->Insert(aDotStr);	// Dummytext to allocate the Section
                             pSh->SttDoc();
-                            pSh->EndDoc(sal_True);	// Alles im Rahmen selektieren
+                            pSh->EndDoc(sal_True);	// Select everything in the frame
                             pSh->InsertSection(aSect);
                         }
                         pSh->Pop( sal_False );
                     }
                     if ( i + 1 != rItem.nRows )
-                        pSh->SplitNode(); // Kleine Optimierung
+                        pSh->SplitNode(); // Small optimisation
                 }
             }
             else
@@ -418,7 +409,7 @@ static sal_uInt16 nBCTitleNo = 0;
             if(!bLabel)
             {
                 uno::Reference< frame::XModel >  xModel = pSh->GetView().GetDocShell()->GetBaseModel();
-                DBG_ASSERT(pDialogFactory, "SwAbstractDialogFactory fail!");
+                OSL_ENSURE(pDialogFactory, "SwAbstractDialogFactory fail!");
                 SwLabDlgMethod SwLabDlgUpdateFieldInformation = pDialogFactory->GetSwLabDlgStaticMethod ();
                 SwLabDlgUpdateFieldInformation(xModel, rItem);
             }
@@ -436,14 +427,14 @@ static sal_uInt16 nBCTitleNo = 0;
 
         if( rItem.aWriting.indexOf( '<' ) >= 0 )
         {
-            // Datenbankbrowser mit zuletzt verwendeter Datenbank oeffnen
+            // Open database browser on recently used database
             ShowDBObj( *pNewView, pSh->GetDBData() );
         }
 
         if( rItem.bSynchron )
         {
             SfxDispatcher* pDisp = pViewFrame->GetDispatcher();
-            ASSERT(pDisp, "Heute kein Dispatcher am Frame?");
+            OSL_ENSURE(pDisp, "No dispatcher in frame?");
             pDisp->Execute(FN_SYNC_LABELS, SFX_CALLMODE_ASYNCHRON);
         }
         rReq.SetReturnValue(SfxVoidItem(bLabel ? FN_LABEL : FN_BUSINESS_CARD));
@@ -455,3 +446,4 @@ static sal_uInt16 nBCTitleNo = 0;
 }
 
 
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
