@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -33,9 +34,7 @@
 
 
 
-#ifndef _VIEW_HXX
 #include <view.hxx>
-#endif
 #include <wrtsh.hxx>
 #include <cption.hxx>
 #include <fldmgr.hxx>
@@ -61,12 +60,8 @@
 #include <com/sun/star/text/XTextFramesSupplier.hpp>
 #include <com/sun/star/text/XTextFrame.hpp>
 
-#ifndef _FRMUI_HRC
 #include <frmui.hrc>
-#endif
-#ifndef _CPTION_HRC
 #include <cption.hrc>
-#endif
 #include <SwStyleNameMapper.hxx>
 using namespace ::com::sun::star;
 
@@ -143,7 +138,7 @@ SwCaptionDialog::SwCaptionDialog( Window *pParent, SwView &rV ) :
     aPrevWin      (this, SW_RES(WIN_SAMPLE  )),
     rView( rV ),
     pMgr( new SwFldMgr(rView.GetWrtShellPtr()) ),
-    bCopyAttributes( FALSE ),
+    bCopyAttributes( sal_False ),
     bOrderNumberingFirst( SW_MOD()->GetModuleConfig()->IsCaptionOrderNumberingFirst() )
 {
     //#i61007# order of captions
@@ -188,7 +183,7 @@ SwCaptionDialog::SwCaptionDialog( Window *pParent, SwView &rV ) :
     {
         nPoolId = RES_POOLCOLL_LABEL_ABB;
         pString = ::GetOldGrfCat();
-        bCopyAttributes = TRUE;
+        bCopyAttributes = sal_True;
         sObjectName = rSh.GetFlyName();
         //if not OLE
         if(!xNameAccess.is())
@@ -346,8 +341,6 @@ IMPL_LINK_INLINE_START( SwCaptionDialog, SelectHdl, ListBox *, EMPTYARG )
 }
 IMPL_LINK_INLINE_END( SwCaptionDialog, SelectHdl, ListBox *, EMPTYARG )
 
-
-
 IMPL_LINK( SwCaptionDialog, ModifyHdl, Edit *, EMPTYARG )
 {
     SwWrtShell &rSh = rView.GetWrtShell();
@@ -382,8 +375,9 @@ IMPL_LINK(SwCaptionDialog, CaptionHdl, PushButton*, EMPTYARG)
 void SwCaptionDialog::DrawSample()
 {
     String aStr;
+    String sCaption = aTextEdit.GetText();
 
-    // Nummer
+    // number
     String sFldTypeName = aCategoryBox.GetText();
     sal_Bool bNone = sFldTypeName == sNone;
     if( !bNone )
@@ -392,7 +386,7 @@ void SwCaptionDialog::DrawSample()
                                         aFormatBox.GetSelectEntryPos() );
         if( SVX_NUM_NUMBER_NONE != nNumFmt )
         {
-            // Kategorie
+            // category
             //#i61007# order of captions
             if( !bOrderNumberingFirst )
             {
@@ -425,7 +419,6 @@ void SwCaptionDialog::DrawSample()
             case SVX_NUM_CHARS_LOWER_LETTER_N:  aStr += 'a'; break;
             case SVX_NUM_ROMAN_UPPER:           aStr += 'I'; break;
             case SVX_NUM_ROMAN_LOWER:           aStr += 'i'; break;
-            //case ARABIC:
             default:                    aStr += '1'; break;
             }
             //#i61007# order of captions
@@ -436,9 +429,12 @@ void SwCaptionDialog::DrawSample()
             }
 
         }
-        aStr += aSepEdit.GetText();
+        if( sCaption.Len() > 0 )
+        {
+            aStr += aSepEdit.GetText();
+        }
     }
-    aStr += aTextEdit.GetText();
+    aStr += sCaption;
     // do preview!
     aPrevWin.SetPreviewText( aStr );
 }
@@ -462,7 +458,7 @@ void SwCaptionDialog::CheckButtonWidth()
             &aOKButton, &aCancelButton, &aHelpButton, &aAutoCaptionButton, &aOptionButton
         };
         Button** pCurrent = pBtns;
-        for ( sal_uInt32 i = 0; i < sizeof( pBtns ) / sizeof( pBtns[ 0 ] ); ++i, ++pCurrent )
+        for ( sal_uInt32 i = 0; i < SAL_N_ELEMENTS(pBtns); ++i, ++pCurrent )
         {
             aNewSize = (*pCurrent)->GetSizePixel();
             aNewSize.Width() += nDelta;
@@ -479,8 +475,6 @@ SwCaptionDialog::~SwCaptionDialog()
 {
     delete pMgr;
 }
-/*  */
-
 
 SwSequenceOptionDialog::SwSequenceOptionDialog( Window *pParent, SwView &rV,
                                             const String& rSeqFldType )
@@ -524,7 +518,7 @@ SwSequenceOptionDialog::SwSequenceOptionDialog( Window *pParent, SwView &rV,
     aLbLevel.SelectEntryPos( nLvl < MAXLEVEL ? nLvl + 1 : 0 );
     aEdDelim.SetText( sDelim );
 
-    ::FillCharStyleListBox( aLbCharStyle, rView.GetDocShell(), TRUE, TRUE );
+    ::FillCharStyleListBox( aLbCharStyle, rView.GetDocShell(), sal_True, sal_True );
     aLbCharStyle.SelectEntryPos( 0 );
 }
 
@@ -549,7 +543,7 @@ void SwSequenceOptionDialog::Apply()
     }
     else if( aFldTypeName.Len() && nLvl < MAXLEVEL )
     {
-        // dann muessen wir das mal einfuegen
+        // then we have to insert that
         SwSetExpFieldType aFldType( rSh.GetDoc(), aFldTypeName, nsSwGetSetExpType::GSE_SEQ );
         aFldType.SetDelimiter( cDelim );
         aFldType.SetOutlineLvl( nLvl );
@@ -562,9 +556,6 @@ void SwSequenceOptionDialog::Apply()
         rSh.UpdateExpFlds();
 }
 
-/*-- 24.08.2004 16:13:53---------------------------------------------------
-
-  -----------------------------------------------------------------------*/
 String  SwSequenceOptionDialog::GetCharacterStyle() const
 {
     String sRet;
@@ -573,9 +564,6 @@ String  SwSequenceOptionDialog::GetCharacterStyle() const
     return sRet;
 }
 
-/*-- 24.08.2004 16:14:00---------------------------------------------------
-
-  -----------------------------------------------------------------------*/
 void    SwSequenceOptionDialog::SetCharacterStyle(const String& rStyle)
 {
     aLbCharStyle.SelectEntryPos(0);
@@ -590,7 +578,7 @@ long SwCaptionDialog::CategoryBox::PreNotify( NotifyEvent& rNEvt )
     {
         const KeyEvent* pEvent = rNEvt.GetKeyEvent();
         const KeyCode&  rKeyCode = pEvent->GetKeyCode();
-        USHORT nTmpCode = rKeyCode.GetFullCode() & ~KEY_ALLMODTYPE;
+        sal_uInt16 nTmpCode = rKeyCode.GetFullCode() & ~KEY_ALLMODTYPE;
 
         if(nTmpCode != KEY_BACKSPACE && nTmpCode != KEY_RETURN
                 && nTmpCode != KEY_TAB && nTmpCode != KEY_ESCAPE)
@@ -609,7 +597,8 @@ long SwCaptionDialog::CategoryBox::PreNotify( NotifyEvent& rNEvt )
         nHandled = ComboBox::PreNotify( rNEvt );
     return nHandled;
 }
-/*-- 01.11.2007 10:45:51---------------------------------------------------
+
+/*-------------------------------------------------------------------------
     //#i61007# order of captions
   -----------------------------------------------------------------------*/
 void lcl_MoveH( Window& rWin, sal_Int32 nMove )
@@ -618,6 +607,7 @@ void lcl_MoveH( Window& rWin, sal_Int32 nMove )
     aPos.Y() += nMove;
     rWin.SetPosPixel(aPos);
 }
+
 void SwCaptionDialog::ApplyCaptionOrder()
 {
     //have the settings changed?
@@ -646,3 +636,5 @@ void SwCaptionDialog::ApplyCaptionOrder()
         SetSizePixel( aDlgSize );
     }
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
