@@ -1,3 +1,4 @@
+/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*- */
 /*************************************************************************
  *
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
@@ -36,9 +37,7 @@
 #define _SVSTDARR_STRINGS
 #include <tools/urlobj.hxx>
 #include <tools/stream.hxx>
-#ifndef _MSGBOX_HXX //autogen
 #include <vcl/msgbox.hxx>
-#endif
 #include <vcl/help.hxx>
 #include <unotools/transliterationwrapper.hxx>
 #include <unotools/tempfile.hxx>
@@ -53,15 +52,9 @@
 #include <glosdoc.hxx>
 #include <swunohelper.hxx>
 
-#ifndef _GLOSBIB_HRC
 #include <glosbib.hrc>
-#endif
-#ifndef _MISC_HRC
 #include <misc.hrc>
-#endif
-#ifndef _HELPID_H
 #include <helpid.h>
-#endif
 
 
 #define PATH_CASE_SENSITIVE 0x01
@@ -69,16 +62,15 @@
 
 #define RENAME_TOKEN_DELIM		(sal_Unicode)1
 
-/*-----------------09.06.97 13:05-------------------
-
---------------------------------------------------*/
 SwGlossaryGroupDlg::SwGlossaryGroupDlg(Window * pParent,
                         const SvStrings* pPathArr,
                         SwGlossaryHdl *pHdl) :
     SvxStandardDialog(pParent, SW_RES(DLG_BIB_BASE)),
-
+    aBibFT(     this, SW_RES(FT_BIB)),
     aNameED( 	this, SW_RES(ED_NAME)),
+    aPathFT(     this, SW_RES(FT_PATH)),
     aPathLB(	this, SW_RES(LB_PATH)),
+    aSelectFT(   this, SW_RES(FT_SELECT)),
     aGroupTLB(  this, SW_RES(TLB_GROUPS)),
 
     aOkPB(      this, SW_RES(BT_OK)),
@@ -87,16 +79,13 @@ SwGlossaryGroupDlg::SwGlossaryGroupDlg(Window * pParent,
     aNewPB(     this, SW_RES(PB_NEW)),
     aDelPB(     this, SW_RES(PB_DELETE)),
     aRenamePB(  this, SW_RES(PB_RENAME)),
-    aBibFT(     this, SW_RES(FT_BIB)),
-    aPathFT(     this, SW_RES(FT_PATH)),
-    aSelectFT(   this, SW_RES(FT_SELECT)),
 
     pRemovedArr(0),
     pInsertedArr(0),
     pRenamedArr(0),
     pGlosHdl(pHdl)
 {
-    USHORT i;
+    sal_uInt16 i;
 
     FreeResource();
 
@@ -107,7 +96,7 @@ SwGlossaryGroupDlg::SwGlossaryGroupDlg(Window * pParent,
 
     aGroupTLB.SetHelpId(HID_GLOS_GROUP_TREE);
     aGroupTLB.SetTabs( &nTabs[0], MAP_APPFONT );
-    aGroupTLB.SetWindowBits(WB_HSCROLL|WB_CLIPCHILDREN|WB_SORT);
+    aGroupTLB.SetStyle(aGroupTLB.GetStyle()|WB_HSCROLL|WB_CLIPCHILDREN|WB_SORT);
     aGroupTLB.SetSelectHdl(LINK(this, SwGlossaryGroupDlg, SelectHdl));
     aGroupTLB.GetModel()->SetSortMode(SortAscending);
     aNewPB.SetClickHdl(LINK(this, SwGlossaryGroupDlg, NewHdl));
@@ -121,7 +110,7 @@ SwGlossaryGroupDlg::SwGlossaryGroupDlg(Window * pParent,
         INetURLObject aTempURL(sPath);
         sPath = aTempURL.GetMainURL(INetURLObject::DECODE_WITH_CHARSET );
         aPathLB.InsertEntry(sPath);
-        ULONG nCaseReadonly = 0;
+        sal_uLong nCaseReadonly = 0;
         utl::TempFile aTempFile(&sPath);
         aTempFile.EnableKillingFile();
         if(!aTempFile.IsValid())
@@ -131,9 +120,9 @@ SwGlossaryGroupDlg::SwGlossaryGroupDlg(Window * pParent,
         aPathLB.SetEntryData(i, (void*)nCaseReadonly);
     }
     aPathLB.SelectEntryPos(0);
-    aPathLB.Enable(TRUE);
+    aPathLB.Enable(sal_True);
 
-    const USHORT nCount = pHdl->GetGroupCnt();
+    const sal_uInt16 nCount = pHdl->GetGroupCnt();
     for(i = 0; i < nCount; ++i)
     {
         String sTitle;
@@ -144,9 +133,8 @@ SwGlossaryGroupDlg::SwGlossaryGroupDlg(Window * pParent,
         pData->sGroupName = sGroup;
         pData->sGroupTitle = sTitle;
         String sTemp(sTitle);
-        //sGroup.GetToken(0, GLOS_DELIM)
         sTemp += '\t';
-        pData->sPath = aPathLB.GetEntry((USHORT)sGroup.GetToken(1, GLOS_DELIM).ToInt32());
+        pData->sPath = aPathLB.GetEntry((sal_uInt16)sGroup.GetToken(1, GLOS_DELIM).ToInt32());
         sTemp += pData->sPath;
         SvLBoxEntry* pEntry = aGroupTLB.InsertEntry(sTemp);
         pEntry->SetUserData(pData);
@@ -155,9 +143,6 @@ SwGlossaryGroupDlg::SwGlossaryGroupDlg(Window * pParent,
     aGroupTLB.GetModel()->Resort();
 }
 
-/*-----------------09.06.97 13:05-------------------
-
---------------------------------------------------*/
 SwGlossaryGroupDlg::~SwGlossaryGroupDlg()
 {
 
@@ -179,11 +164,7 @@ SwGlossaryGroupDlg::~SwGlossaryGroupDlg()
 
 }
 
-/*-----------------09.06.97 13:11-------------------
-
---------------------------------------------------*/
-
-void __EXPORT SwGlossaryGroupDlg::Apply()
+void SwGlossaryGroupDlg::Apply()
 {
     if(aNewPB.IsEnabled())
         NewHdl(&aNewPB);
@@ -192,8 +173,8 @@ void __EXPORT SwGlossaryGroupDlg::Apply()
 
     if(pRemovedArr && pRemovedArr->Count())
     {
-        USHORT nCount = pRemovedArr->Count();
-        for(USHORT i = 0; i < nCount; ++i)
+        sal_uInt16 nCount = pRemovedArr->Count();
+        for(sal_uInt16 i = 0; i < nCount; ++i)
         {
             const String* pDelEntry = (*pRemovedArr)[i];
             const String sDelGroup = pDelEntry->GetToken(0, '\t');
@@ -224,8 +205,8 @@ void __EXPORT SwGlossaryGroupDlg::Apply()
     //erst umbenennen, falls es schon eins gab
     if(pRenamedArr && pRenamedArr->Count())
     {
-        USHORT nCount = pRenamedArr->Count();
-        for(USHORT i = 0; i < nCount; ++i)
+        sal_uInt16 nCount = pRenamedArr->Count();
+        for(sal_uInt16 i = 0; i < nCount; ++i)
         {
             String * pEntry = (*pRenamedArr)[i];
             xub_StrLen nStrSttPos = 0;
@@ -239,8 +220,8 @@ void __EXPORT SwGlossaryGroupDlg::Apply()
     }
     if(pInsertedArr && pInsertedArr->Count())
     {
-        USHORT nCount = pInsertedArr->Count();
-        for(USHORT i = 0; i < nCount; ++i)
+        sal_uInt16 nCount = pInsertedArr->Count();
+        for(sal_uInt16 i = 0; i < nCount; ++i)
         {
             String sNewGroup = *(*pInsertedArr)[i];
             String sNewTitle = sNewGroup.GetToken(0, GLOS_DELIM);
@@ -253,20 +234,18 @@ void __EXPORT SwGlossaryGroupDlg::Apply()
         }
     }
 }
-/*-----------------09.06.97 13:12-------------------
 
---------------------------------------------------*/
 IMPL_LINK( SwGlossaryGroupDlg, SelectHdl, SvTabListBox*, EMPTYARG  )
 {
-    aNewPB.Enable(FALSE);
+    aNewPB.Enable(sal_False);
     SvLBoxEntry* pFirstEntry = aGroupTLB.FirstSelected();
     if(pFirstEntry)
     {
         GlosBibUserData* pUserData = (GlosBibUserData*)pFirstEntry->GetUserData();
         String sEntry(pUserData->sGroupName);
         String sName(aNameED.GetText());
-        BOOL bExists = FALSE;
-        ULONG nPos = aGroupTLB.GetEntryPos(sName, 0);
+        sal_Bool bExists = sal_False;
+        sal_uLong nPos = aGroupTLB.GetEntryPos(sName, 0);
         if( 0xffffffff > nPos)
         {
             SvLBoxEntry* pEntry = aGroupTLB.GetEntry(nPos);
@@ -281,21 +260,16 @@ IMPL_LINK( SwGlossaryGroupDlg, SelectHdl, SvTabListBox*, EMPTYARG  )
     return 0;
 }
 
-/*-----------------09.06.97 13:22-------------------
-
---------------------------------------------------*/
 IMPL_LINK( SwGlossaryGroupDlg, NewHdl, Button*, EMPTYARG )
 {
     String sGroup(aNameED.GetText());
-//	sGroup.ToLower();
     sGroup += GLOS_DELIM;
     sGroup += String::CreateFromInt32(aPathLB.GetSelectEntryPos());
-    DBG_ASSERT(!pGlosHdl->FindGroupName(sGroup), "Gruppe bereits vorhanden!");
+    OSL_ENSURE(!pGlosHdl->FindGroupName(sGroup), "group already available!");
     if(!pInsertedArr)
         pInsertedArr = new SvStrings;
     pInsertedArr->Insert(new String(sGroup), pInsertedArr->Count());
     String sTemp(aNameED.GetText());
-//	sTemp.ToLower();
     sTemp += '\t';
     sTemp += aPathLB.GetSelectEntry();
     SvLBoxEntry* pEntry = aGroupTLB.InsertEntry(sTemp);
@@ -310,32 +284,30 @@ IMPL_LINK( SwGlossaryGroupDlg, NewHdl, Button*, EMPTYARG )
 
     return 0;
 }
-/*-----------------09.06.97 13:22-------------------
 
---------------------------------------------------*/
 IMPL_LINK( SwGlossaryGroupDlg, DeleteHdl, Button*, pButton  )
 {
     SvLBoxEntry* pEntry = aGroupTLB.FirstSelected();
     if(!pEntry)
     {
-        pButton->Enable(FALSE);
+        pButton->Enable(sal_False);
         return 0;
     }
     GlosBibUserData* pUserData = (GlosBibUserData*)pEntry->GetUserData();
     String sEntry(pUserData->sGroupName);
     // befindet sich der zu loeschende Name schon unter den
     // den neuen - dann weg damit
-    BOOL bDelete = TRUE;
+    sal_Bool bDelete = sal_True;
     if(pInsertedArr && pInsertedArr->Count())
     {
-        USHORT nCount = pInsertedArr->Count();
-        for(USHORT i = 0; i < nCount; ++i)
+        sal_uInt16 nCount = pInsertedArr->Count();
+        for(sal_uInt16 i = 0; i < nCount; ++i)
         {
             const String* pTemp = (*pInsertedArr)[i];
             if(*pTemp == sEntry)
             {
                 pInsertedArr->Remove(i);
-                bDelete = FALSE;
+                bDelete = sal_False;
                 break;
             }
 
@@ -346,15 +318,15 @@ IMPL_LINK( SwGlossaryGroupDlg, DeleteHdl, Button*, pButton  )
     {
         if(pRenamedArr && pRenamedArr->Count())
         {
-            USHORT nCount = pRenamedArr->Count();
-            for(USHORT i = 0; i < nCount; ++i)
+            sal_uInt16 nCount = pRenamedArr->Count();
+            for(sal_uInt16 i = 0; i < nCount; ++i)
             {
                 const String* pTemp = (*pRenamedArr)[i];
                 String sTemp( pTemp->GetToken(0, RENAME_TOKEN_DELIM ));
                 if(sTemp == sEntry)
                 {
                     pRenamedArr->Remove(i);
-                    bDelete = FALSE;
+                    bDelete = sal_False;
                     break;
                 }
             }
@@ -372,15 +344,12 @@ IMPL_LINK( SwGlossaryGroupDlg, DeleteHdl, Button*, pButton  )
     delete pUserData;
     aGroupTLB.GetModel()->Remove(pEntry);
     if(!aGroupTLB.First())
-        pButton->Enable(FALSE);
+        pButton->Enable(sal_False);
     //the content must be deleted - otherwise the new handler would be called in Apply()
     aNameED.SetText(aEmptyStr);
     return 0;
 }
 
-/* -----------------23.11.98 12:26-------------------
- *
- * --------------------------------------------------*/
 IMPL_LINK( SwGlossaryGroupDlg, RenameHdl, Button *, EMPTYARG )
 {
     SvLBoxEntry* pEntry = aGroupTLB.FirstSelected();
@@ -393,22 +362,22 @@ IMPL_LINK( SwGlossaryGroupDlg, RenameHdl, Button *, EMPTYARG )
 
     sNewName += GLOS_DELIM;
     sNewName += String::CreateFromInt32(aPathLB.GetSelectEntryPos());
-    DBG_ASSERT(!pGlosHdl->FindGroupName(sNewName), "Gruppe bereits vorhanden!");
+    OSL_ENSURE(!pGlosHdl->FindGroupName(sNewName), "group already available!");
 
     // befindet sich der umzubenennende Name unter den
     // den neuen - dann austauschen
-    BOOL bDone = FALSE;
+    sal_Bool bDone = sal_False;
     if(pInsertedArr && pInsertedArr->Count())
     {
-        USHORT nCount = pInsertedArr->Count();
-        for(USHORT i = 0; i < nCount; ++i)
+        sal_uInt16 nCount = pInsertedArr->Count();
+        for(sal_uInt16 i = 0; i < nCount; ++i)
         {
             const String* pTemp = (*pInsertedArr)[i];
             if(*pTemp == sEntry)
             {
                 pInsertedArr->Remove(i);
                 pInsertedArr->Insert(new String(sNewName), pInsertedArr->Count());
-                bDone = TRUE;
+                bDone = sal_True;
                 break;
             }
         }
@@ -426,7 +395,6 @@ IMPL_LINK( SwGlossaryGroupDlg, RenameHdl, Button *, EMPTYARG )
     delete (GlosBibUserData*)pEntry->GetUserData();
     aGroupTLB.GetModel()->Remove(pEntry);
     String sTemp(aNameED.GetText());
-//	sTemp.ToLower();
     sTemp += '\t';
     sTemp += aPathLB.GetSelectEntry();
     pEntry = aGroupTLB.InsertEntry(sTemp);
@@ -440,24 +408,21 @@ IMPL_LINK( SwGlossaryGroupDlg, RenameHdl, Button *, EMPTYARG )
     aGroupTLB.GetModel()->Resort();
     return 0;
 }
-/*-----------------09.06.97 13:42-------------------
 
---------------------------------------------------*/
 IMPL_LINK( SwGlossaryGroupDlg, ModifyHdl, Edit*, EMPTYARG )
 {
     String sEntry(aNameED.GetText());
-//	sEntry.ToLower();
-    BOOL bEnableNew = TRUE;
-    BOOL bEnableDel = FALSE;
-    ULONG nCaseReadonly =
-            (ULONG)aPathLB.GetEntryData(aPathLB.GetSelectEntryPos());
-    BOOL bDirReadonly = 0 != (nCaseReadonly&PATH_READONLY);
+    sal_Bool bEnableNew = sal_True;
+    sal_Bool bEnableDel = sal_False;
+    sal_uLong nCaseReadonly =
+            (sal_uLong)aPathLB.GetEntryData(aPathLB.GetSelectEntryPos());
+    sal_Bool bDirReadonly = 0 != (nCaseReadonly&PATH_READONLY);
 
     if(!sEntry.Len() || bDirReadonly)
-        bEnableNew = FALSE;
+        bEnableNew = sal_False;
     else if(sEntry.Len())
     {
-        ULONG nPos = 0xffffffff;
+        sal_uLong nPos = 0xffffffff;
 
 
         nPos = aGroupTLB.GetEntryPos(sEntry, 0);
@@ -465,12 +430,12 @@ IMPL_LINK( SwGlossaryGroupDlg, ModifyHdl, Edit*, EMPTYARG )
         if( 0xffffffff == nPos)
         {
             const ::utl::TransliterationWrapper& rSCmp = GetAppCmpStrIgnore();
-            for(USHORT i = 0; i < aGroupTLB.GetEntryCount(); i++)
+            for(sal_uInt16 i = 0; i < aGroupTLB.GetEntryCount(); i++)
             {
                 String sTemp = aGroupTLB.GetEntryText( i, 0 );
-                nCaseReadonly = (ULONG)aPathLB.GetEntryData(
+                nCaseReadonly = (sal_uLong)aPathLB.GetEntryData(
                     aPathLB.GetEntryPos(aGroupTLB.GetEntryText(i,1)));
-                BOOL bCase = 0 != (nCaseReadonly & PATH_CASE_SENSITIVE);
+                sal_Bool bCase = 0 != (nCaseReadonly & PATH_CASE_SENSITIVE);
 
                 if( !bCase && rSCmp.isEqual( sTemp, sEntry ))
                 {
@@ -481,7 +446,7 @@ IMPL_LINK( SwGlossaryGroupDlg, ModifyHdl, Edit*, EMPTYARG )
         }
         if( 0xffffffff > nPos)
         {
-            bEnableNew = FALSE;
+            bEnableNew = sal_False;
             aGroupTLB.Select(aGroupTLB.GetEntry( nPos ));
             aGroupTLB.MakeVisible(aGroupTLB.GetEntry( nPos ));
         }
@@ -491,11 +456,6 @@ IMPL_LINK( SwGlossaryGroupDlg, ModifyHdl, Edit*, EMPTYARG )
     {
         GlosBibUserData* pUserData = (GlosBibUserData*)pEntry->GetUserData();
         bEnableDel = IsDeleteAllowed(pUserData->sGroupName);
-
-//		String sGroup = aGroupTLB.GetEntryText(pEntry, 0);
-//		sGroup += GLOS_DELIM;
-//		sGroup += String::CreateFromInt32(aPathLB.GetEntryPos(aGroupTLB.GetEntryText(pEntry, 1)));
-//		bEnableDel = IsDeleteAllowed(sGroup);
     }
 
     aDelPB.Enable(bEnableDel);
@@ -504,27 +464,23 @@ IMPL_LINK( SwGlossaryGroupDlg, ModifyHdl, Edit*, EMPTYARG )
     return 0;
 }
 
-/*------------------------------------------------------------------------
- Beschreibung:
-------------------------------------------------------------------------*/
-
-BOOL SwGlossaryGroupDlg::IsDeleteAllowed(const String &rGroup)
+sal_Bool SwGlossaryGroupDlg::IsDeleteAllowed(const String &rGroup)
 {
-    BOOL bDel = (!pGlosHdl->IsReadOnly(&rGroup));
+    sal_Bool bDel = (!pGlosHdl->IsReadOnly(&rGroup));
 
     // OM: befindet sich der Name unter den den neuen Bereichsnamen,
     // dann ist er auch loeschbar! Bei noch nicht existenten Bereichsnamen
-    // liefert ReadOnly naemlich TRUE.
+    // liefert ReadOnly naemlich sal_True.
 
     if(pInsertedArr && pInsertedArr->Count())
     {
-        USHORT nCount = pInsertedArr->Count();
-        for(USHORT i = 0; i < nCount; ++i)
+        sal_uInt16 nCount = pInsertedArr->Count();
+        for(sal_uInt16 i = 0; i < nCount; ++i)
         {
             const String* pTemp = (*pInsertedArr)[i];
             if(*pTemp == rGroup)
             {
-                bDel = TRUE;
+                bDel = sal_True;
                 break;
             }
         }
@@ -533,9 +489,6 @@ BOOL SwGlossaryGroupDlg::IsDeleteAllowed(const String &rGroup)
     return bDel;
 }
 
-/*-----------------18.07.97 19:06-------------------
-
---------------------------------------------------*/
 void FEdit::KeyInput( const KeyEvent& rKEvent )
 {
     KeyCode aCode = rKEvent.GetKeyCode();
@@ -545,9 +498,7 @@ void FEdit::KeyInput( const KeyEvent& rKEvent )
         SVT_SEARCHPATH_DELIMITER != rKEvent.GetCharCode() )
         Edit::KeyInput( rKEvent );
 }
-/* -----------------------------08.02.00 15:07--------------------------------
 
- ---------------------------------------------------------------------------*/
 void 	SwGlossaryGroupTLB::RequestHelp( const HelpEvent& rHEvt )
 {
     Point aPos( ScreenToOutputPixel( rHEvt.GetMousePosPixel() ));
@@ -578,3 +529,5 @@ void 	SwGlossaryGroupTLB::RequestHelp( const HelpEvent& rHEvt )
         }
     }
 }
+
+/* vim:set shiftwidth=4 softtabstop=4 expandtab: */
